# coding=utf-8

from .fetion import sendMessage, sendFetionGroupMessage, \
        sendFetionGroupsMessage, addFetionFriend, \
        sendFetionAllGroupsMessage, \
        sendWeather, sendGroupWeather
